@@ -34,6 +34,7 @@ Roles and nodes for GitHub issues and Pull Requests.
 
 # stdlib
 import warnings
+import xml.sax.saxutils
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 # 3rd party
@@ -326,6 +327,8 @@ def get_issue_title(issue_url: str) -> Optional[str]:
 
 	if r.status_code == 200:
 		soup = BeautifulSoup(r.content, "html5lib")
-		return soup.find_all("span", attrs={"class": "js-issue-title"})[0].contents[0].strip().strip()
+		content = soup.find_all("span", attrs={"class": "js-issue-title"})[0].text
+		content = xml.sax.saxutils.escape(content).replace('"', "&quot;")
+		return content.strip()
 
 	return None
